ChatMode class

Constructors

ChatMode({required String systemPrompt, List<DataSource>? dataSources})
Creates a new instance of ChatMode with the provided systemPrompt and optional dataSources.

Properties

dataSources → List<DataSource>?
List of data sources that the agent can access to provide more relevant information.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemPrompt → String
System prompt is the instruction provided to agent and used to set the context and guide the agent on how to respond to the user request.
final
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process() → Future<Map<String, dynamic>>
Internal method used by dash_agent to convert the shared Commmand to json formated cofiguration that is deployable.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited