Metadata class

Constructors

Metadata({required String name, String? avatarProfile, List<String> tags = const <String>[]})

Properties

avatarProfile → String?
Relative path of the avatar image for your agent. The supported formats are png or jpeg. Additionally, the image ratio should be 1:1 and max size should not exceed 512*512 pixel. This will be used as the avatar for the agent.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the agent that will be displayed to developer. It doesn't necessary have to be unique similar to agent id defined in pubspec.yaml file.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>
List of tags that are associated with the agent.
final
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process() → Future<Map<String, dynamic>>
Internal method used by dash_agent to convert the shared Commmand to json formated cofiguration that is deployable.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited