DirectoryFiles class

DirectoryFiles is used to add files from a directory to DataSource which can be later used for referncing by Agent.

Example:

final directory = Directory('path-to-directory');
final directoryObject = FileDataObject.fromDirectory(directory);
Inheritance

Constructors

DirectoryFiles(Directory directory, {bool includePaths = false, String? relativeTo, RegExp? regex})

Properties

directory → Directory
Directory object that contains relevant files that will be used by the agent as a reference
final
hashCode → int
The hash code for this object.
no setterinherited
includePaths → bool
bool for specifying whether the file path should be saved as well or excluded from saving. By default, it is false
final
minCliVersion → String
no setteroverride
regex → RegExp?
Optional parameter to perform filetring of the files present in a directory for saving.
final
relativeTo → String?
Optional parameter to share the parent path of the directory
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process() → Future<Map<String, dynamic>>
Internal method used by dash_agent to convert the shared DataSource to json format that can be sent on the web
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited