TextObject class

TextObject is used to add String data to DataSource which can be later used for referecing by Agent

Example:

String firebaseDoc = '<firebase-doc>';
final firebaseDocObject = ProjectDataObject.fromText(firebaseDoc);
Inheritance

Constructors

TextObject(String text)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
minCliVersion → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
text representing the data from the project that will be used by the agent as reference
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process() → Future<Map<String, dynamic>>
Internal method used by dash_agent to convert the shared DataSource to json format that can be sent on the web
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited