WebPage class

WebPage is used to add web page content to the DataSource in the cloud which can be later used for referencing by Agent.

Example:

final webUrl = 'https://sampleurl.com';
final webPageObject = WebDataObject.fromWebPage(webUrl, deepCrawl = false);
Inheritance

Constructors

WebPage(String url, {bool deepCrawl = false})
Creates a new WebPage object.

Properties

deepCrawl → bool
Boolean value for enabling deep crawl of the website if set to true. Default is false
final
hashCode → int
The hash code for this object.
no setterinherited
minCliVersion → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
url of the web page that contains the content that you want to save for referencing.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process() → Future<Map<String, dynamic>>
Internal method used by dash_agent to convert the shared DataSource to json format that can be sent on the web
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited