MatchDocumentStep class

Find matching documents from provided datasources.

Example:

// Datasources
final DataSource docsSource;

// Inputs
final userQuery = StringInput('Your query', optional: false);
final codeAttachment = CodeInput('Primary method');

// Output
final matchingDocuments = MatchDocumentOuput()

return [MatchDocumentStep(query: '$userQuery$codeAttachment', dataSources: [docsSource], output: matchingDocuments)]
Inheritance

Constructors

MatchDocumentStep({required String query, required List<DataSource> dataSources, required MatchDocumentOuput output})

Properties

dashOutputs → List<DashOutput>
no setteroverride
dataSources → List<DataSource>
List of datasources to query relevant documents from.
final
hashCode → int
The hash code for this object.
no setterinherited
output → MatchDocumentOuput
Stores matching documents to be used in the further steps.
final
query → String
String interpolated query with mix of inputs and outputs.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process() → Future<Map<String, dynamic>>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited