PromptQueryStep class

Perform a message request to the model with your customized prompt.

Example:

final promptOutput = PromptOutput();
return [
  PromptQueryStep(
    prompt: '''You are an X agent. Here is the $userQuery, here is the $codeAttachment $matchingCode and the document references: $matchingDocuments. Answer the user's query.''',
    promptOutput: promptOutput,
  )
];
Inheritance

Constructors

PromptQueryStep({required String prompt, PromptOutput? promptOutput, CodeOutput? codeOutput})

Properties

codeOutput → CodeOutput?
codeOutput is experimental and is not adviced for usage. 🚨
final
dashOutputs → List<DashOutput>
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
prompt → String
String interpolated prompt with mix of inputs and outputs.
final
promptOutput → PromptOutput?
Response received from the message request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process() → Future<Map<String, dynamic>>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited