Step class abstract

Step is a single operation in a series for a command.

Supported Step Examples: MatchDocumentStep, WorkspaceQueryStep, PromptQueryStep, AppendToChatStep etc

Implementers

Constructors

Step()

Properties

dashOutputs → List<DashOutput>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process() → Future<Map<String, dynamic>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited