DashInput class abstract

Base class to accept inputs from the user.

Inheritance
Implementers

Constructors

DashInput(String displayText, {bool optional = false})

Properties

displayText → String
Hint Text
final
hashCode → int
The hash code for this object.
no setterinherited
optional → bool
Marks the input as optional.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process() → Future<Map<String, dynamic>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited